Creates a styled and formatted table to represent the summary case situation of COVID19 in each country.

Easykable(n_country)

Arguments

n_country

The number of the countries with most confirmed cases in the data to be formatted in table.

Value

A formatted table of the COVID data set with the specific obervations.