This function can provide a more concise way to select desired input in the Shiny App

Inputselect(ID, chosen_column)

Arguments

ID

The variable which shows the specific content of the cases chose by the user

chosen_column

The column in the specific data set which chose by users to show in the Shiny App

Value

A shiny control which can choose the specfic inputs for the following presentation in the Shiny app

Examples

if (FALSE) { Inputselect("country", corona_table$country) }