Easykable: Create a formatted and stylish table contains the Covid-19...

Description Usage Arguments Value

View source: R/Easykable.R

Description

Creates a styled and formatted table to represent the summary case situation of COVID19 in each country.

Usage

1
Easykable(n_country)

Arguments

n_country

The number of the countries with most confirmed cases in the data to be formatted in table.

Value

A formatted table of the COVID data set with the specific obervations.


etc5523-2020/r-package-assessment-Year-97 documentation built on Jan. 1, 2021, 1:11 a.m.