Description Usage Arguments Value
Creates a styled and formatted table to represent the summary case situation of COVID19 in each country.
1 | Easykable(n_country)
|
n_country |
The number of the countries with most confirmed cases in the data to be formatted in table. |
A formatted table of the COVID data set with the specific obervations.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.