Inputselect: Run the shiny:selectInput for the Covid-19 app

Description Usage Arguments Value Examples

View source: R/Inputselect.R

Description

This function can provide a more concise way to select desired input in the Shiny App

Usage

1
Inputselect(ID, chosen_column)

Arguments

ID

The variable which shows the specific content of the cases chose by the user

chosen_column

The column in the specific data set which chose by users to show in the Shiny App

Value

A shiny control which can choose the specfic inputs for the following presentation in the Shiny app

Examples

1
2
3
4
## Not run: 
Inputselect("country", corona_table$country)

## End(Not run) 

etc5523-2020/r-package-assessment-Year-97 documentation built on Jan. 1, 2021, 1:11 a.m.